==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/LegendBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendMouseButtonEventArgsDescriptionMetadata } from "./LegendMouseButtonEventArgsDescriptionMetadata";
import { LegendMouseEventArgsDescriptionMetadata } from "./LegendMouseEventArgsDescriptionMetadata";
/**
 * @hidden
 */
export let LegendBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class LegendBaseDescriptionMetadata extends Base {
        static e(a) {
            a.item("Background", "(wf:BackColor/ColorTransform)Brush");
        }
        static b(a) {
            if (LegendBaseDescriptionMetadata.a == null) {
                LegendBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LegendBaseDescriptionMetadata.c(LegendBaseDescriptionMetadata.a);
            }
            if (a.k(LegendBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(LegendBaseDescriptionMetadata.a);
            LegendMouseButtonEventArgsDescriptionMetadata.d(a);
            LegendMouseEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("LegendItemMouseLeftButtonDownRef", "EventRef::legendItemMouseLeftButtonDown");
            a.item("LegendItemMouseLeftButtonUpRef", "EventRef::legendItemMouseLeftButtonUp");
            a.item("LegendItemMouseEnterRef", "EventRef::legendItemMouseEnter");
            a.item("LegendItemMouseLeaveRef", "EventRef::legendItemMouseLeave");
            a.item("LegendItemMouseMoveRef", "EventRef::legendItemMouseMove");
            LegendBaseDescriptionMetadata.e(a);
        }
        static d(a) {
            LegendBaseDescriptionMetadata.b(a);
            a.ac("LegendBase", LegendBaseDescriptionMetadata.a);
        }
    }
    LegendBaseDescriptionMetadata.$t = markType(LegendBaseDescriptionMetadata, 'LegendBaseDescriptionMetadata');
    LegendBaseDescriptionMetadata.a = null;
    return LegendBaseDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/LegendBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendMouseButtonEventArgsDescriptionMetadata } from "./LegendMouseButtonEventArgsDescriptionMetadata";
import { LegendMouseEventArgsDescriptionMetadata } from "./LegendMouseEventArgsDescriptionMetadata";
/**
 * @hidden
 */
export let LegendBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class LegendBaseDescriptionMetadata extends Base {
        static e(a) {
            a.item("Background", "(wf:BackColor/ColorTransform)Brush");
        }
        static b(a) {
            if (LegendBaseDescriptionMetadata.a == null) {
                LegendBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LegendBaseDescriptionMetadata.c(LegendBaseDescriptionMetadata.a);
            }
            if (a.k(LegendBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(LegendBaseDescriptionMetadata.a);
            LegendMouseButtonEventArgsDescriptionMetadata.d(a);
            LegendMouseEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("LegendItemMouseLeftButtonDownRef", "EventRef::legendItemMouseLeftButtonDown");
            a.item("LegendItemMouseLeftButtonUpRef", "EventRef::legendItemMouseLeftButtonUp");
            a.item("LegendItemMouseEnterRef", "EventRef::legendItemMouseEnter");
            a.item("LegendItemMouseLeaveRef", "EventRef::legendItemMouseLeave");
            a.item("LegendItemMouseMoveRef", "EventRef::legendItemMouseMove");
            LegendBaseDescriptionMetadata.e(a);
        }
        static d(a) {
            LegendBaseDescriptionMetadata.b(a);
            a.ad("LegendBase", LegendBaseDescriptionMetadata.a);
        }
    }
    LegendBaseDescriptionMetadata.$t = markType(LegendBaseDescriptionMetadata, 'LegendBaseDescriptionMetadata');
    LegendBaseDescriptionMetadata.a = null;
    return LegendBaseDescriptionMetadata;
})();
